@@ -244,9 +244,7 @@ class RestAPI(object):
 		# handle success.
 		return r3sponse.success_response(f"Successfully canceled {count} subscriptions from user [{uid}].")
 
-		#
-
-		
+		#	
 	def get_customer_id(self, 
 		# the user's uid.
 		uid=None,
@@ -530,8 +528,9 @@ class RestAPI(object):
 		# ...
 
 		# RESET RATES FOR TESTING.
-		data["requests"] = 0
-		edits += 1
+		#if not PRODUCTION:
+		#	data["requests"] = 0
+		#	edits += 1
 
 		# save edits.
 		if edits > 0:
